"use strict";
var path = require("path");
var fs = require("fs");
var parse_1 = require("./parse");
var resolvePkg = require("resolve-pkg");
var readFile = require("fs-readfile-promise");
var unixify = require("unixify");
var isRelative = require("is-relative-path");
var defaults = {
    baseDir: "."
};
function node(nameOrFile, options) {
    if (options === void 0) { options = defaults; }
    var file;
    var baseDir = options.baseDir, parent = options.parent;
    var module = parent ? parent : nameOrFile;
    if (isRelative(nameOrFile)) {
        file = findFile(baseDir, nameOrFile);
    }
    else {
        var packageDir = resolvePkg(nameOrFile, { cwd: baseDir });
        var packageFile = path.join(packageDir, "package.json");
        var typings = require(packageFile).typings;
        if (!typings) {
            return Promise.resolve([]);
        }
        file = findFile(packageDir, typings);
    }
    var dirname = path.dirname(file);
    dirname = unixify(dirname);
    return readFile(file, "utf8")
        .then(function (sourceText) {
        var o = Object.assign({}, options, { module: module, file: file, dirname: dirname });
        return parse_1.parse(sourceText, o);
    });
}
exports.node = node;
function findFile(baseDir, name) {
    var checkExtensions = ["", ".ts", ".d.ts"];
    var file;
    for (var i = 0; i < checkExtensions.length; ++i) {
        var extFile = name + checkExtensions[i];
        file = path.resolve(baseDir, extFile);
        if (fs.existsSync(file)) {
            var stat = fs.statSync(file);
            if (stat.isDirectory())
                continue;
            break;
        }
    }
    return file;
}
exports.findFile = findFile;
//# sourceMappingURL=node.js.map